=====================
MEGARA Analysis Tools
=====================

|zenodo| |pypi|

Tools for the analysis and visualization of data from the MEGARA, 
the optical Integral-Field Unit and Multi-Object Spectrograph
designed for the Gran telescopio Canarias (GTC).

You can install `megara-tools` using
the `released code in PyPI <https://pypi.org/project/megara-tools/>`_ or
the `development version in Github <https://github.com/guaix-ucm/megara-tools>`_.

Licensing
---------

megara-tools is distributed under GNU GPL, either version 3 of the License,
or (at your option) any later version. See the file LICENSE.txt for details.

Authors
-------

Contact point: Armando Gil de Paz <agil@fis.ucm.es>

The full list of authors is available in `AUTHORS.rst <AUTHORS.rst>`_ in 
the source distribution.

.. |zenodo| image:: https://zenodo.org/badge/DOI/10.5281/zenodo.3931924.svg
    :target: https://doi.org/10.5281/zenodo.3931924
    :alt: Zenodo DOI

.. |pypi| image:: https://badge.fury.io/py/megara-tools.svg
    :target: https://badge.fury.io/py/megara-tools
    :alt: PyPI status

